@@ -1,6 +1,6 @@
 # Classes related to schedules
 
-from .core import *
+from homealone.core import *
 from .sunriseset import *
 
 # day of week identifiers
